#
# spec file for package python-pysrt
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pysrt
Version:        1.1.2
Release:        bp153.1.16
Summary:        SubRip (.srt) subtitle parser and writer
License:        GPL-3.0-only
URL:            https://github.com/byroot/pysrt
Source0:        https://files.pythonhosted.org/packages/source/p/pysrt/pysrt-%{version}.tar.gz
BuildRequires:  %{python_module base}
BuildRequires:  %{python_module chardet}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-chardet
Requires(post):   update-alternatives
Requires(postun):  update-alternatives
BuildArch:      noarch
%python_subpackages

%description
pysrt is a python library to search and download subtitles.
It comes with an easy to use CLI suitable for direct use or cron jobs.

%prep
%setup -q -n pysrt-%{version}
# Remove shebang from non-executable file
sed -e '1d' -i pysrt/commands.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/srt
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative srt

%postun
%python_uninstall_alternative srt

%files %{python_files}
%doc README.rst
%python_alternative %{_bindir}/srt
%{python_sitelib}/pysrt
%{python_sitelib}/pysrt-%{version}-py%{python_version}.egg-info

%changelog
* Tue May  5 2020 Matej Cepl <mcepl@suse.com>
- Don't use %%python3_only command, but properly use alternatives.
* Fri Apr 17 2020 Paolo Stivanin <info@paolostivanin.com>
- Use pytest instead of nose
* Mon Jan 20 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.1.2
  * open(): don't use universal 'U' mode
  * Switched broken pypip.in badges to shields.io
  * to use print in py2 and py3, print from __future__
  * if file not exist show message
  * Add Python 3 trove classifiers
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Fri Mar 31 2017 aloisio@gmx.com
- Set correct group
* Wed Mar 29 2017 aloisio@gmx.com
- Fixed source URL
* Tue Mar 28 2017 aloisio@gmx.com
- Converted to single-spec
- Added tests
- Dropped python-pysrt-rpmlintrc (those are pertinent warnings)
* Thu Dec 15 2016 aloisio@gmx.com
- Update to version 1.1.1
  * Include tests in release source tarball
  changes introduced in version 1.1.0:
  * Make character_per_seconds correctly deal with tags and
    introduce text_without_tags property
  * Get rid of unused builtin_str
  * pep8
  * Fix conding style
  * Make str() method of SrtItem function properly in both
    Python 2 and 3
  * Make SrtFile.encoding be set when autodetecting encoding
  * Handle division by zero in characters_per_second
  * Implement SubRipItem.characters_per_second
  * Add duration property to SubRipItem
* Tue Feb 10 2015 aloisio@gmx.com
- Initial version 1.0.1
